from paquete1.modulo1 import Cliente, ClientePremium
from paquete1.modulo2 import menu



def gestionar_cliente():#aca podemos harcodear un cliente para hacer pruebas

    cliente1 = Cliente("Juan", 24, "juan@hotmail.com", "netbook, tecnologia")
    cliente1.agregar_al_carrito("libro", 2)
    cliente1.ver_carrito()
    cliente1.comprar("Amazon")
    print(cliente1)

def gestionar_cliente_premium():#aca podemos harcodear un cliente premium para hacer pruebas
    cliente_premium = ClientePremium("Maria", 30, "maria@hotmail.com", "ropa, comida", 0.2)
    cliente_premium.agregar_al_carrito("zapatos", 1)
    cliente_premium.ver_carrito()
    cliente_premium.comprar("eBay", 300)
    print(cliente_premium)



def main():# o menu_pruebas
    while True:
        print("--------------------------")
        print("--- MENÚ DE PRUEBAS ---")
        print("--------------------------")
        print("1. Gestionar Cliente")
        print("2. Gestionar Usuarios")
        print("3. Cliente Premium")
        print("4. Salir")

        opcion = input("Seleccione una opción: ")

        if opcion == "1":
            gestionar_cliente()
        elif opcion == "2":
            menu()#los usuarios son tratados como clientes
        elif opcion == "3":
            gestionar_cliente_premium()
        elif opcion == "4":
            print("👋 Saliendo...")
            break
        else:
            print("❌⚠️ Opción inválida. Intente nuevamente.❌⚠️")

# Ejecutar
main()





class Cliente:
    def __init__(self, nombre, edad, email, gustos=None):
        self.nombre = nombre
        self.edad = edad
        self.email = email
        self.gustos = gustos
        if gustos is None:
            self.gustos = []

        self.carrito = []

    def __str__(self):
        return f"Cliente(nombre={self.nombre}, edad={self.edad}, email={self.email}, gustos={self.gustos}, carrito={self.carrito})"
    
    def agregar_al_carrito(self, producto, cantidad=1):#si no le pasan nada se le asigna 1 por defecto
        self.carrito.append({"producto": producto, "cantidad": cantidad})
        print(f"{self.nombre} agregó {cantidad} {producto}(s) al carrito.")

    def ver_carrito(self):
        if not self.carrito:
            print("🛒 El carrito está vacío.")
        else:
            print("🛒 Carrito actual:")
            for item in self.carrito:
                print(f"- {item['cantidad']} x {item['producto']}")

    def comprar(self, tienda):
        if not self.carrito:
            print(f"{self.nombre} no tiene productos en el carrito para comprar.")
        else:
            print(f"{self.nombre} ha comprado los siguientes productos en {tienda}:")
            for item in self.carrito:
                print(f"- {item['cantidad']} x {item['producto']}")
            self.carrito.clear()







class ClientePremium(Cliente):
    def __init__(self, nombre, edad, email, gustos=None, descuento=0.1):
        super().__init__(nombre, edad, email, gustos)
        self.descuento = descuento

    def comprar(self, tienda, precio):
        if not self.carrito:
            print(f"{self.nombre} no tiene productos en el carrito para comprar.")
        else:
            total = sum(item["cantidad"] for item in self.carrito) * precio
            total_con_descuento = total - (total * self.descuento)
            print(f"{self.nombre} ha comprado los siguientes productos en {tienda}:")
            for item in self.carrito:
                print(f"- {item['cantidad']} x {item['producto']}")
            print(f"Total a pagar (con descuento del {self.descuento * 100}%): ${total_con_descuento:.2f}")
            self.carrito.clear()

        